tlslite.messages.ServerKeyExchange

Package tlslite :: Module messages :: Class ServerKeyExchange |
[hide private]
[frames] | no frames]

# Class ServerKeyExchange

source code

    HandshakeMsg --+
                   |
                  ServerKeyExchange

Instance Methods | [hide private]
__init__(self, cipherSuite) | source code
createDH(self, dh_p, dh_g, dh_Ys) | source code
createSRP(self, srp_N, srp_g, srp_s, srp_B) | source code
hash(self, clientRandom, serverRandom) | source code
parse(self, p) | source code
write(self) | source code
Inherited from `HandshakeMsg`: `postWrite`

Method Details | [hide private]

### __init__(self, cipherSuite) (Constructor) | source code
Overrides: HandshakeMsg.__init__